diff lisp/faces.el @ 90192:173dee4e2611

Revision: miles@gnu.org--gnu-2005/emacs--unicode--0--patch-61 Merge from emacs--cvs-trunk--0 Patches applied: * emacs--cvs-trunk--0 (patch 353-357) - Update from CVS
author Miles Bader <miles@gnu.org>
date Thu, 09 Jun 2005 07:13:03 +0000
parents 01137c1fdbe9 bd94b75dbfe8
children a1b34dec1104
line wrap: on
line diff
--- a/lisp/faces.el	Mon Jun 06 04:18:31 2005 +0000
+++ b/lisp/faces.el	Thu Jun 09 07:13:03 2005 +0000
@@ -2085,13 +2085,32 @@
   :group 'whitespace		; like `show-trailing-whitespace'
   :group 'basic-faces)
 
-(defface escape-glyph '((((background dark)) :foreground "cyan")
-			;; See the comment in minibuffer-prompt for
-			;; the reason not to use blue on MS-DOS.
-			(((type pc)) :foreground "magenta")
-			(t :foreground "blue"))
+(defface escape-glyph
+  '((((background dark)) :foreground "pink2")
+    ;; See the comment in minibuffer-prompt for
+    ;; the reason not to use blue on MS-DOS.
+    (((type pc)) :foreground "magenta")
+    ;; red4 is too light -- rms.
+    (t :foreground "blue"))
   "Face for characters displayed as ^-sequences or \-sequences."
-  :group 'basic-faces)
+  :group 'basic-faces
+  :version "22.1")
+
+(defface no-break-space
+  '((((class color) (min-colors 88)) :inherit escape-glyph :underline t)
+    (((class color) (min-colors 8)) :background "magenta" :foreground )
+    (t :inverse-video t))
+  "Face for non-breaking space."
+  :group 'basic-faces
+  :version "22.1")
+
+(defface shadow
+  '((((background dark))  :foreground "grey70")
+    (((background light)) :foreground "grey50"))
+  "Basic face for shadowed text."
+  :group 'basic-faces
+  :version "22.1")
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Manipulating font names.